import 'dart:math';

import 'package:flutter/material.dart';

import 'package:awale/config/default_game_settings.dart';
import 'package:awale/models/settings/settings_game.dart';
import 'package:awale/models/settings/settings_global.dart';
import 'package:awale/utils/tools.dart';

class ParameterPainter extends CustomPainter {
  const ParameterPainter({
    required this.code,
    required this.value,
    required this.isSelected,
    required this.gameSettings,
    required this.globalSettings,
  });

  final String code;
  final String value;
  final bool isSelected;
  final GameSettings gameSettings;
  final GlobalSettings globalSettings;

  @override
  void paint(Canvas canvas, Size size) {
    // force square
    final double canvasSize = min(size.width, size.height);

    const Color borderColorEnabled = Colors.blue;
    const Color borderColorDisabled = Colors.white;

    // "enabled/disabled" border
    final paint = Paint();
    paint.style = PaintingStyle.stroke;
    paint.color = isSelected ? borderColorEnabled : borderColorDisabled;
    paint.strokeJoin = StrokeJoin.round;
    paint.strokeWidth = 10;
    canvas.drawRect(
        Rect.fromPoints(const Offset(0, 0), Offset(canvasSize, canvasSize)), paint);

    // content
    switch (code) {
      case DefaultGameSettings.parameterCodeGameMode:
        paintGameModeParameterItem(value, canvas, canvasSize);
        break;
      default:
        printlog('Unknown parameter: $code/$value');
        paintUnknownParameterItem(value, canvas, canvasSize);
    }
  }

  @override
  bool shouldRepaint(CustomPainter oldDelegate) {
    return false;
  }

  // "unknown" parameter -> simple block with text
  void paintUnknownParameterItem(
    final String value,
    final Canvas canvas,
    final double size,
  ) {
    final paint = Paint();
    paint.strokeJoin = StrokeJoin.round;
    paint.strokeWidth = 3;

    paint.color = Colors.grey;
    paint.style = PaintingStyle.fill;
    canvas.drawRect(Rect.fromPoints(const Offset(0, 0), Offset(size, size)), paint);

    final textSpan = TextSpan(
      text: '?\n$value',
      style: const TextStyle(
        color: Colors.black,
        fontSize: 18,
        fontWeight: FontWeight.bold,
      ),
    );
    final textPainter = TextPainter(
      text: textSpan,
      textDirection: TextDirection.ltr,
      textAlign: TextAlign.center,
    );
    textPainter.layout();
    textPainter.paint(
      canvas,
      Offset(
        (size - textPainter.width) * 0.5,
        (size - textPainter.height) * 0.5,
      ),
    );
  }

  void paintGameModeParameterItem(
    final String value,
    final Canvas canvas,
    final double size,
  ) {
    String text = '';
    Color baseColor = Colors.grey;

    switch (value) {
      case DefaultGameSettings.gameModeHumanVsHuman:
        text = '🧑 🧑';
        baseColor = Colors.green;
        break;
      case DefaultGameSettings.gameModeHumanVsRobot:
        text = '🧑 🤖';
        baseColor = Colors.pink;
        break;
      case DefaultGameSettings.gameModeRobotVsHuman:
        text = '🤖 🧑';
        baseColor = Colors.pink;
        break;
      case DefaultGameSettings.gameModeRobotVsRobot:
        text = '🤖 🤖';
        baseColor = Colors.brown;
        break;
      default:
    }

    final paint = Paint();
    paint.strokeJoin = StrokeJoin.round;
    paint.strokeWidth = 3;

    paint.color = baseColor;
    paint.style = PaintingStyle.fill;
    canvas.drawRect(Rect.fromPoints(const Offset(0, 0), Offset(size, size)), paint);

    final textSpan = TextSpan(
      text: text,
      style: const TextStyle(
        color: Colors.black,
        fontSize: 22,
        fontWeight: FontWeight.bold,
      ),
    );
    final textPainter = TextPainter(
      text: textSpan,
      textDirection: TextDirection.ltr,
      textAlign: TextAlign.center,
    );
    textPainter.layout();
    textPainter.paint(
      canvas,
      Offset(
        (size - textPainter.width) * 0.5,
        (size - textPainter.height) * 0.5,
      ),
    );
  }
}
