import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:awale/cubit/game_cubit.dart';
import 'package:awale/ui/widgets/game/game_house.dart';
import 'package:awale/ui/widgets/game/game_score.dart';

class GameBoardWidget extends StatelessWidget {
  const GameBoardWidget({
    super.key,
    required this.houseSize,
  });

  final double houseSize;

  @override
  Widget build(BuildContext context) {
    return Center(
      child: BlocBuilder<GameCubit, GameState>(
        builder: (BuildContext context, GameState gameState) {
          final Color borderColor = Theme.of(context).colorScheme.onSurface;

          Widget house(int houseIndex) {
            return SizedBox(
              width: houseSize,
              height: houseSize,
              child: GameHouseWidget(cellIndex: houseIndex),
            );
          }

          return Container(
            margin: const EdgeInsets.all(2),
            padding: const EdgeInsets.all(2),
            decoration: BoxDecoration(
              color: borderColor,
              borderRadius: BorderRadius.circular(40),
              border: Border.all(
                color: borderColor,
                width: 6,
              ),
            ),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                SizedBox(
                  width: 2 * houseSize,
                  height: houseSize,
                  child: const GameScoreWidget(playerIndex: 1),
                ),
                Table(
                  defaultColumnWidth: const IntrinsicColumnWidth(),
                  children: [
                    TableRow(children: [house(0), house(11)]),
                    TableRow(children: [house(1), house(10)]),
                    TableRow(children: [house(2), house(9)]),
                    TableRow(children: [house(3), house(8)]),
                    TableRow(children: [house(4), house(7)]),
                    TableRow(children: [house(5), house(6)]),
                  ],
                ),
                SizedBox(
                  width: 2 * houseSize,
                  height: houseSize,
                  child: const GameScoreWidget(playerIndex: 0),
                ),
              ],
            ),
          );
        },
      ),
    );
  }
}
