import 'package:awale/utils/color_extensions.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:awale/cubit/game_cubit.dart';
import 'package:awale/models/game/game.dart';
import 'package:awale/ui/widgets/game/game_seeds.dart';

class GamePlayerWidget extends StatelessWidget {
  const GamePlayerWidget({
    super.key,
    required this.playerIndex,
    required this.widgetSize,
  });

  final int playerIndex;
  final double widgetSize;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;

        final bool isCurrentPlayer = (currentGame.currentPlayer == playerIndex);
        final int seedsCount = isCurrentPlayer ? currentGame.currentHand : 0;

        final Color baseColor = isCurrentPlayer
            ? (currentGame.isPlayerHuman(playerIndex) ? Colors.pink : Colors.grey)
            : Theme.of(context).colorScheme.surface;

        return Container(
          margin: const EdgeInsets.all(2),
          padding: const EdgeInsets.all(2),
          decoration: BoxDecoration(
            color: baseColor,
            borderRadius: BorderRadius.circular(6),
            border: Border.all(
              color: baseColor.darken(),
              width: 6,
            ),
          ),
          width: widgetSize,
          height: widgetSize,
          child: GameSeedsWidget(seedsCount: seedsCount),
        );
      },
    );
  }
}
