import 'package:awale/utils/color_extensions.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:awale/cubit/game_cubit.dart';
import 'package:awale/models/game/game.dart';

class GameScoreWidget extends StatelessWidget {
  const GameScoreWidget({
    super.key,
    required this.playerIndex,
  });

  final int playerIndex;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;

        final bool isCurrentPlayer = (currentGame.currentPlayer == playerIndex);

        final baseColor =
            isCurrentPlayer ? Colors.white : const Color.fromARGB(255, 230, 230, 230);

        return Container(
          margin: const EdgeInsets.all(2),
          padding: const EdgeInsets.all(2),
          decoration: BoxDecoration(
            color: baseColor,
            borderRadius: BorderRadius.circular(100),
            border: Border.all(
              color: baseColor.darken(),
              width: 4,
            ),
          ),
          width: 100,
          child: RotatedBox(
            quarterTurns: 1 + 2 * playerIndex,
            child: Padding(
              padding: const EdgeInsets.fromLTRB(0, 65, 0, 0),
              child: Text(
                currentGame.scores[playerIndex].toString(),
                textAlign: TextAlign.center,
                style: TextStyle(
                  fontSize: 40,
                  fontWeight: FontWeight.bold,
                  color: Theme.of(context).colorScheme.primary,
                ),
              ),
            ),
          ),
        );
      },
    );
  }
}
