import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:awale/cubit/game_cubit.dart';
import 'package:awale/models/game/game.dart';

class GameSeedsWidget extends StatelessWidget {
  const GameSeedsWidget({
    super.key,
    required this.seedsCount,
  });

  final int seedsCount;

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game currentGame = gameState.currentGame;
        final String skin = currentGame.globalSettings.skin;

        const ratioScale = 0.2;
        const ratioTranslate = 0.65;

        const List<List<double>> layout = [
          [0, 0], // 1
          [10, -17], // 2
          [20, 0], // 3
          [10, 17], // 4
          [-10, 17], // 5
          [-20, 0], // 6
          [-10, -17], // 7
          [0, -34], // 8
          [20, -34], // 9
          [30, -17], // 10
          [40, 0], // 11
          [30, 17], // 12
          [20, 34], // 13
          [0, 34], // 14
          [-20, 34], // 15
          [-30, 17], // 16
          [-40, 0], // 17
          [-30, -17], // 18
          [-20, -34], // 19
        ];

        double minX = 0;
        double maxX = 0;
        double minY = 0;
        double maxY = 0;

        for (int i = 0; i < seedsCount; i++) {
          final List<double> seedLocation = layout[i];

          maxX = max(maxX, seedLocation[0]);
          minX = min(minX, seedLocation[0]);
          maxY = max(maxY, seedLocation[1]);
          minY = min(minY, seedLocation[1]);
        }

        final double deltaX = minX + (maxX - minX) / 2;
        final double deltaY = minY + (maxY - minY) / 2;

        List<Widget> seeds = [];
        for (int i = 0; i < seedsCount; i++) {
          final List<double> seedLocation = layout[i];
          seeds.add(
            Transform.translate(
              offset: Offset(
                ratioTranslate * (seedLocation[0] - deltaX),
                ratioTranslate * (seedLocation[1] - deltaY),
              ),
              child: Transform.scale(
                scale: ratioScale,
                child: Image.asset('assets/skins/${skin}_seed.png'),
              ),
            ),
          );
        }

        return Stack(
          children: seeds,
        );
      },
    );
  }
}
